@@ -6,7 +6,7 @@ from markdown_it.token import Token
 from mdformat.renderer import _container_renderers, _token_renderers
 from mdformat.renderer._util import MARKERS, removesuffix
 
-__all__ = ("MDRenderer", "MARKERS")
+__all__ = ("MDRenderer", "MARKERS", "LOGGER")
 
 LOGGER = logging.getLogger(__name__)
 
@@ -123,9 +123,9 @@ class MDRenderer:
     @staticmethod
     def _write_references(env: dict) -> str:
         text = ""
-        for key in sorted(env.get("used_refs", [])):
-            ref = env["references"][key]
-            item = f"[{key.lower()}]: {ref['href']}"
+        for label in sorted(env.get("used_refs", [])):
+            ref = env["references"][label]
+            item = f"[{label.lower()}]: {ref['href']}"
             if ref["title"]:
                 item += f' "{ref["title"]}"'
             text += item + "\n"
